@@ -1,3 +1,5 @@
+from bitfield import BitField
+from bitfield.forms import BitFieldCheckboxSelectMultiple
 from django.contrib import admin
 from django.contrib.contenttypes.admin import GenericTabularInline
 
@@ -6,7 +8,9 @@ from image_assets import models, forms
 
 @admin.register(models.get_asset_type_model())
 class AssetTypeAdmin(admin.ModelAdmin):
-    pass
+    formfield_overrides = {
+        BitField: {'widget': BitFieldCheckboxSelectMultiple},
+    }
 
 
 class AssetsInline(GenericTabularInline):
